==> ejc-lz-impl-3.0.0-20220309.065506-10-sources.jar: com/ejianc/business/base/vo/SupplierbankVO.java <==
package com.ejianc.business.base.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 供应商银行账号
 * 
 * @author generator
 * 
 */
public class SupplierbankVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 银行账号编码
    private Long manageId; // 供应商管理档案ID
    private String supplyName; // 供应商名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private String supplyBank; // 开户银行名称
    private String supplyAccount; // 开户银行账号
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long changeId; // 变更单据id
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    @ReferSerialTransfer(referCode="SuppliermanageRef")
    public Long getManageId() {
        return manageId;
    }

    @ReferDeserialTransfer
    public void setManageId(Long manageId) {
        this.manageId = manageId;
    }
    public String getSupplyName() {
        return supplyName;
    }

    public void setSupplyName(String supplyName) {
        this.supplyName = supplyName;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getSupplyBank() {
        return supplyBank;
    }

    public void setSupplyBank(String supplyBank) {
        this.supplyBank = supplyBank;
    }
    public String getSupplyAccount() {
        return supplyAccount;
    }

    public void setSupplyAccount(String supplyAccount) {
        this.supplyAccount = supplyAccount;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }
    
}

==> ejc-lz-impl-3.0.0-20220427.010753-66-sources.jar: com/ejianc/business/base/vo/SupplierbankVO.java <==
package com.ejianc.business.base.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 供应商银行账号
 * 
 * @author generator
 * 
 */
public class SupplierbankVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 银行账号编码
    private Long manageId; // 供应商管理档案ID
    private String supplyName; // 供应商名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private String supplyBank; // 开户银行名称
    private String supplyAccount; // 开户银行账号
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long changeId; // 变更单据id
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    @ReferSerialTransfer(referCode="SupplierinfoRef")
    public Long getManageId() {
        return manageId;
    }

    @ReferDeserialTransfer
    public void setManageId(Long manageId) {
        this.manageId = manageId;
    }
    public String getSupplyName() {
        return supplyName;
    }

    public void setSupplyName(String supplyName) {
        this.supplyName = supplyName;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getSupplyBank() {
        return supplyBank;
    }

    public void setSupplyBank(String supplyBank) {
        this.supplyBank = supplyBank;
    }
    public String getSupplyAccount() {
        return supplyAccount;
    }

    public void setSupplyAccount(String supplyAccount) {
        this.supplyAccount = supplyAccount;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }
    
}
